@@ -4,14 +4,12 @@ import csv
 import pandas.compat as compat
 from pandas import DataFrame
 
+from pandas_datareader.base import _BaseReader
 
 _yahoo_codes = {'symbol': 's', 'last': 'l1', 'change_pct': 'p2', 'PE': 'r',
                 'time': 't1', 'short_ratio': 's7'}
 
 
-from pandas_datareader.base import _BaseReader
-
-
 class YahooQuotesReader(_BaseReader):
 
     """Get current yahoo quote"""
@@ -26,8 +24,11 @@ class YahooQuotesReader(_BaseReader):
             sym_list = self.symbols
         else:
             sym_list = '+'.join(self.symbols)
-        # for codes see: http://www.gummy-stuff.org/Yahoo-data.htm
-        request = ''.join(compat.itervalues(_yahoo_codes))  # code request string
+
+        # For codes see: http://www.gummy-stuff.org/Yahoo-data.htm
+        #
+        # Construct the code request string.
+        request = ''.join(compat.itervalues(_yahoo_codes))
         params = {'s': sym_list, 'f': request}
         return params
 
